********************
API Reference
********************

Scilab2Py
=========
.. module:: scilab2py
.. autoclass:: Scilab2Py
   :members:

Utils
=====

.. autoclass:: Scilab2PyError

.. autofunction:: get_log

.. autoclass:: Struct

.. autofunction:: kill_scilab
